summaryrefslogtreecommitdiffstats
path: root/tools/h5repack/h5repack.c
diff options
context:
space:
mode:
Diffstat (limited to 'tools/h5repack/h5repack.c')
-rw-r--r--tools/h5repack/h5repack.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/h5repack/h5repack.c b/tools/h5repack/h5repack.c
index a6a6989..37ef3d1 100644
--- a/tools/h5repack/h5repack.c
+++ b/tools/h5repack/h5repack.c
@@ -73,8 +73,8 @@ int h5repack(const char* infile,
if (check_objects(infile,options)<0)
return -1;
- /* copy the file */
- if (copy_file(infile,outfile,options)<0)
+ /* copy the objects */
+ if (copy_objects(infile,outfile,options)<0)
return -1;